import hashlib, binascii

def generate_password_digest(username, secret_key, length=6):
  dk = hashlib.pbkdf2_hmac('sha256', username.encode(), secret_key.encode(), 25000)
  password_digest = binascii.hexlify(dk).decode()

  return password_digest[:length]



from .passwordhash import generate_password_digest
# To let the password script be run where JupyterHub isn't installed:
try:
  from .hashauthenticator import HashAuthenticator
except ImportError:
  print("Warning: Unable to import HashAuthenticator.\n"
        "Only generate_password_digest will be available.")
  HashAuthenticator = None


__all__ = ['HashAuthenticator', 'generate_password_digest']



from jupyterhub.auth import Authenticator
from tornado import gen
from traitlets import Unicode, Integer
from .passwordhash import generate_password_digest

class HashAuthenticator(Authenticator):
  secret_key = Unicode(
    config=True,
    help="Key used to encrypt usernames to produce passwords."
  )

  password_length = Integer(
    default_value=6,
    config=True,
    help="Password length.")

  @gen.coroutine
  def authenticate(self, handler, data):
    username = data['username']
    password = data['password']

    expected_password = generate_password_digest(username, self.secret_key, self.password_length)

    if password == expected_password:
      return username

    return None



from setuptools import setup

setup(
    name='jupyterhub-hashauthenticator',
    version='0.2.0',
    description='Hashed Password Authenticator for JupyterHub',
    url='https://github.com/thedataincubator/jupyterhub-hashauthenticator',
    author='Petko Minkov',
    author_email='pminkov@gmail.com',
    maintainer='Robert Schroll',
    maintainer_email='robert@thedataincubator.com',
    scripts=['scripts/hashauthpw', 'scripts/hashauthservice'],
    install_requires=['jupyterhub'],
    test_suite="hashauthenticator.tests",
    license='BSD3',
    packages=['hashauthenticator'],
)
